@@ -2,3 +2,6 @@ from .base import Transform, TransformChain
 from .homogeneous import *
 from .thinplatesplines import ThinPlateSplines
 from .piecewiseaffine import PiecewiseAffine
+from .rbf import R2LogR2RBF, R2LogRRBF
+
+from .groupalign.procrustes import GeneralizedProcrustesAnalysis
